==> visual-third-party-1.0-sources.jar: com/tenqube/visual_third/core/BulkLoader.java <==
package com.tenqube.visual_third.core;


import android.content.Context;
import android.database.Cursor;
import android.net.Uri;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;

import com.tenqube.visual_third.model.TranCompany;

import java.util.ArrayList;
import java.util.Calendar;

import retrofit2.Call;
import retrofit2.Callback;
import retrofit2.Response;
import tenqube.parser.BulkSmsAdapter;
import tenqube.parser.OnNetworkResultListener;
import tenqube.parser.constants.Constants;
import tenqube.parser.core.ParserService;
import tenqube.parser.model.SMS;
import tenqube.parser.model.Transaction;

import static com.tenqube.visual_third.util.Utils.getConvertedDate;

class BulkLoader implements BulkSmsAdapter {

    private final Context mContext;
    private Cursor mCursor;
    private final Handler mHandler;
    private final OnSmsLoadFinished onSmsLoadFinished;

    private ParserService parserService;
    private VisualApi api;

    /**
     * @param context 컨텍스트
     * @param handler 진행상태 메세지 전송 handler
     */
    public BulkLoader(Context context,
                      Handler handler,
                      OnSmsLoadFinished onSmsLoadFinished) {

        this.mContext = context;
        this.mHandler = handler;
        this.onSmsLoadFinished = onSmsLoadFinished;

        parserService = ParserService.getInstance(context);
        parserService.setDebugMode(true);
        api = VisualApi.getInstance(context);



    }

    public void doParsing() {

        // cursor 초기화
        initCursor();

        // syncParsingRule()
        parserService.syncParsingRule(api.syncParsingRule());

        // parseBulk
        parserService.parseBulk(this);

    }

    private void initCursor() {
        try {
            Uri uri = Uri.parse("content://sms/inbox");
            mCursor = mContext.getContentResolver().query(uri, null, getWhere(), null, "date asc");
            if (mCursor != null) {
                mCursor.moveToFirst();
            }
        } catch (Exception e) {
            onError(1);
        }

    }

    private String getWhere() {
        Calendar calendar = Calendar.getInstance();
        calendar.add(Calendar.MONTH, -6);
        return   "date > " + calendar.getTimeInMillis();
    }

    @Override
    public int getSmsCount() {
        return mCursor == null ? 0 : mCursor.getCount();
    }

    @Override
    public SMS getSmsAt(int n) {
        return getSMS();
    }

    private SMS getSMS() {
        SMS sms = null;
        if (mCursor != null) {
            sms = new SMS(mCursor.getInt(mCursor.getColumnIndex("_id")),
                mCursor.getString(mCursor.getColumnIndex("body")),
                mCursor.getString(mCursor.getColumnIndex("address")),
                mCursor.getString(mCursor.getColumnIndex("address")),
                getConvertedDate(mCursor.getLong(mCursor.getColumnIndex("date"))),
                Constants.SMSType.SMS.ordinal());
            mCursor.moveToNext();
        }

        return sms;
    }

    /**
     * @param now 현재 내역 수
     * @param total 전체 내역 수
     */
    @Override
    public void onProgress(int now, int total) {
        //ui 변경
        int percent = ((now * 100) / total) + 1;

        Bundle data = new Bundle();
        data.putInt("percent", percent);
        data.putInt("now", now);
        data.putInt("total", total);


        sendHandlerMsg(data,
                1,
                percent);
    }

    /**
     * 구버전의 경우 v1형태에 맞게 구성후 검색서버 반영되면 변경 처리
     * doGrouping
     * @param transactions 파싱된 지출내역 목록
     * @param callback 성공여부 콜백 메소드
     */
    @Override
    public void sendToServerTransactions(ArrayList<Transaction> transactions, final OnNetworkResultListener callback) {

        // 서버 전송
        api.sendToServerTransactionsWithAsync(transactions, new Callback<TranCompany>() {
            @Override
            public void onResponse(Call<TranCompany> call, Response<TranCompany> response) {
                callback.onResult(true);
            }

            @Override
            public void onFailure(Call<TranCompany> call, Throwable t) {
                callback.onResult(true);
            }
        });

    }



    @Override
    public void onCompleted() {

        sendHandlerMsg(null, 0, 0);

        if(mCursor != null)
            mCursor.close();

        if(onSmsLoadFinished != null)
            onSmsLoadFinished.onFinished(false);
    }



    @Override
    public void onError(final int resultCode) {

        //파싱룰 동기화가 필요한경우
        sendHandlerMsg(null, 0, 0);

        if(mCursor != null)
            mCursor.close();

        if(onSmsLoadFinished != null)
            onSmsLoadFinished.onFinished(true);
    }

    private void sendHandlerMsg(Bundle data, int what, int arg1) {

        if(mHandler != null) {
            Message hMsg = mHandler.obtainMessage();
            if(data != null) hMsg.setData(data);
            hMsg.what = what;
            hMsg.arg1 = arg1;
            mHandler.sendMessage(hMsg);
        }
    }


    public interface OnSmsLoadFinished {
        void onFinished(boolean isError);
    }


}

==> visual-third-party-1.5-sources.jar: com/tenqube/visual_third/core/BulkLoader.java <==
package com.tenqube.visual_third.core;


import android.content.Context;
import android.database.Cursor;
import android.net.Uri;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;

import com.tenqube.visual_third.model.TranCompany;

import java.util.ArrayList;
import java.util.Calendar;

import retrofit2.Call;
import retrofit2.Callback;
import retrofit2.Response;
import tenqube.parser.BulkSmsAdapter;
import tenqube.parser.OnNetworkResultListener;
import tenqube.parser.constants.Constants;
import tenqube.parser.core.ParserService;
import tenqube.parser.model.SMS;
import tenqube.parser.model.Transaction;

import static com.tenqube.visual_third.util.Utils.getConvertedDate;

class BulkLoader implements BulkSmsAdapter {

    private final Context mContext;
    private Cursor mCursor;
    private final Handler mHandler;
    private final OnSmsLoadFinished onSmsLoadFinished;

    private ParserService parserService;
    private VisualApi api;

    /**
     * @param context 컨텍스트
     * @param handler 진행상태 메세지 전송 handler
     */
    public BulkLoader(Context context,
                      Handler handler,
                      OnSmsLoadFinished onSmsLoadFinished) {

        this.mContext = context;
        this.mHandler = handler;
        this.onSmsLoadFinished = onSmsLoadFinished;

        parserService = ParserService.getInstance(context);
        parserService.setDebugMode(true);
        api = VisualApi.getInstance(context);



    }

    public void doParsing() {

        // cursor 초기화
        initCursor();

        // syncParsingRule()
        parserService.syncParsingRule(api.syncParsingRule());

        // parseBulk
        parserService.parseBulk(this);

    }

    private void initCursor() {
        try {
            Uri uri = Uri.parse("content://sms/inbox");
            mCursor = mContext.getContentResolver().query(uri, null, getWhere(), null, "date asc");
            if (mCursor != null) {
                mCursor.moveToFirst();
            }
        } catch (Exception e) {
            onError(1);
        }

    }

    private String getWhere() {
        Calendar calendar = Calendar.getInstance();
        calendar.add(Calendar.MONTH, -6);
        return   "date > " + calendar.getTimeInMillis();
    }

    @Override
    public int getSmsCount() {
        return mCursor == null ? 0 : mCursor.getCount();
    }

    @Override
    public SMS getSmsAt(int n) {
        return getSMS();
    }

    private SMS getSMS() {
        SMS sms = null;
        if (mCursor != null) {
            sms = new SMS(mCursor.getInt(mCursor.getColumnIndex("_id")),
                mCursor.getString(mCursor.getColumnIndex("body")),
                mCursor.getString(mCursor.getColumnIndex("address")),
                mCursor.getString(mCursor.getColumnIndex("address")),
                getConvertedDate(mCursor.getLong(mCursor.getColumnIndex("date"))),
                Constants.SMSType.SMS.ordinal());
            mCursor.moveToNext();
        }

        return sms;
    }

    /**
     * @param now 현재 내역 수
     * @param total 전체 내역 수
     */
    @Override
    public void onProgress(int now, int total) {
        //ui 변경
        int percent = ((now * 100) / total) + 1;

        Bundle data = new Bundle();
        data.putInt("percent", percent);
        data.putInt("now", now);
        data.putInt("total", total);


        sendHandlerMsg(data,
                1,
                percent);
    }

    /**
     * 구버전의 경우 v1형태에 맞게 구성후 검색서버 반영되면 변경 처리
     * doGrouping
     * @param transactions 파싱된 지출내역 목록
     * @param callback 성공여부 콜백 메소드
     */
    @Override
    public void sendToServerTransactions(ArrayList<Transaction> transactions, final OnNetworkResultListener callback) {

        // 서버 전송
        api.searchCompany(transactions, new Callback<TranCompany>() {
            @Override
            public void onResponse(Call<TranCompany> call, Response<TranCompany> response) {
                callback.onResult(true);
            }

            @Override
            public void onFailure(Call<TranCompany> call, Throwable t) {
                callback.onResult(true);
            }
        });

    }



    @Override
    public void onCompleted() {

        sendHandlerMsg(null, 0, 0);

        if(mCursor != null)
            mCursor.close();

        if(onSmsLoadFinished != null)
            onSmsLoadFinished.onFinished(false);
    }



    @Override
    public void onError(final int resultCode) {

        //파싱룰 동기화가 필요한경우
        sendHandlerMsg(null, 0, 0);

        if(mCursor != null)
            mCursor.close();

        if(onSmsLoadFinished != null)
            onSmsLoadFinished.onFinished(true);
    }

    private void sendHandlerMsg(Bundle data, int what, int arg1) {

        if(mHandler != null) {
            Message hMsg = mHandler.obtainMessage();
            if(data != null) hMsg.setData(data);
            hMsg.what = what;
            hMsg.arg1 = arg1;
            mHandler.sendMessage(hMsg);
        }
    }


    public interface OnSmsLoadFinished {
        void onFinished(boolean isError);
    }


}
